# -*- coding: utf-8 -*-
import datetime

from django.core.paginator import Paginator, InvalidPage, EmptyPage
from django.shortcuts import get_object_or_404
from django.template import RequestContext
from django.shortcuts import render_to_response
from django.db.models import Q
from django.views.generic.list_detail import object_list

from news.models import News
from news.forms import RicercaNewsForm


def news_detail(request, object_id, template='news/news_detail.html', extra_context=None):
    if extra_context is None: extra_context = {}
    news = get_object_or_404(News, pk=object_id)
    extra_context.update({'news':news})
    return render_to_response(template,
                              extra_context,
                              context_instance=RequestContext(request))
    
def retrieve_news(request, category=None, anno=None, mese=None, parola_chiave=None, sort='DESC', paginate_by=5):
    # se arrivo da un post devo mostrare una lista dall'inizio
    filtered = False
    page = 1
    if request.method == 'POST':
        filtered=True
        form = RicercaNewsForm(request.POST)
        if form.is_valid():
            anno = int(form.cleaned_data['anno'])
            if form.cleaned_data['mese'] == 'None':
                mese = None
            else:
                mese = int(form.cleaned_data['mese'])
            parola_chiave = form.cleaned_data['parola_chiave']
    # altrimenti sono all'interno di una navigazione paginata
    else:
        form = RicercaNewsForm()
        page = int(request.GET.get('page', '1'))
        # se i parametri anno e mese hanno un valore non None ci inizializzo
        # le variabili per i filtri di ricerca
        try:
            anno = int(request.GET.get('anno').replace('.','')) # ? mette un punto dopo il 2 !
        except:
            anno = None
        try:
            mese = int(request.GET.get('mese'))
        except:
            mese = None

    # listo le news con data di pubblicazione corrente
#    qs = News.active.filter(pub_date_begin__lte=datetime.datetime.now(),
#                              pub_date_end__gte=datetime.datetime.now())
    qs = News.active.all()
    # escludo le news non in categoria richiesta
    if category:
        qs = qs.filter(categories__name__in=[category])
    # escludo le news fuori dalla data specificata
    if anno and not mese:
        qs = qs.filter(event_date__lte=datetime.date(anno +1 , 1, 1),
                           event_date__gte=datetime.date(anno, 1, 1))
    else:
        if anno and mese:
            qs = qs.filter(event_date__lte=datetime.date(anno, mese+1, 1),
                              event_date__gte=datetime.date(anno, mese, 1))
            
    # escludo le news che non contengono le parola chiave
    if parola_chiave:
        for p in parola_chiave.split():
            qs = qs.filter(text__icontains=p)        

    order_by = '-event_date'
    if sort=='ASC':
        order_by = 'event_date'
    qs = qs.order_by(order_by)        
    return object_list(request, queryset=qs, paginate_by=paginate_by, page=page,
                       template_name='news/news_archive.html', extra_context=locals())

#
#def news_list(request, template='news/news_list.html'):
#    try:
#        paginator = Paginator(CatalogCategory.objects.all(), 25) # Show 25 contacts per page
#    except CatalogCategory.DoesNotExist:
#        pass
#
#    # Make sure page request is an int. If not, deliver first page.
#    try:
#        page = int(request.GET.get('page', '1'))
#    except ValueError:
#        page = 1
#
#    # If page request (9999) is out of range, deliver last page of results.
#    try:
#        catalog_category = paginator.page(page)
#    except:
#        catalog_category = paginator.page(paginator.num_pages)
#
#    ctx = {
#        'catalog_category': category,
#    }
#
#    return render_to_response(template, context_instance=RequestContext(request, ctx))